DartFileAnalyzer class
Constructors
- DartFileAnalyzer({required ImportAnalyzer importAnalyzer})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- importAnalyzer → ImportAnalyzer
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyzeFile(
{required String relativePath, required String content}) → DartFileAnalyzerResult -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited