ProjectAnalysisResult class

Constructors

ProjectAnalysisResult({required ProjectGraph graph, required String packageName, required bool isFlutterProject, required List<SourceFile> sourceFiles, required List<SourceFile> testFiles, required List<String> warnings})

Properties

graph ProjectGraph
final
hashCode int
The hash code for this object.
no setterinherited
isFlutterProject bool
final
packageName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceFiles List<SourceFile>
final
testFiles List<SourceFile>
final
warnings List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited