SymbolAnalyzer class

Constructors

SymbolAnalyzer({required String projectRoot, required String packageName})

Properties

hashCode int
The hash code for this object.
no setterinherited
packageName String
final
projectRoot String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

analyzeProject() Future<SymbolAnalysisResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited