SymbolImpactAnalyzer class

Constructors

SymbolImpactAnalyzer({required SymbolGraph symbolGraph, required List<SourceFile> discoveredTests, required ImpactAnalyzer fallbackFileAnalyzer})

Properties

discoveredTests List<SourceFile>
final
fallbackFileAnalyzer ImpactAnalyzer
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbolGraph SymbolGraph
final

Methods

analyzeSymbolImpact({required List<String> changedFiles, List<String>? changedSymbolIds, Duration analysisDuration = Duration.zero, bool isGitRepo = true, bool gitRequiresFallback = false, String? gitFallbackReason, bool isConservative = false, bool forceAll = false, bool hasAnalysisErrors = false, String? analysisErrorReason}) ImpactResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited