ImpactResult class

Constructors

ImpactResult({required List<String> changedFiles, required List<AffectedTestReason> affectedTests, required List<String> unaffectedTests, required int totalTests, Duration analysisDuration = Duration.zero, String status = 'safe', String mode = 'default', bool isFallback = false, String? fallbackReason, String? fallbackExplanation, String analysisLevel = 'file', List<String> changedSymbols = const [], List<SymbolImpactPath> impactPaths = const []})

Properties

affectedCount int
no setter
affectedTests List<AffectedTestReason>
final
analysisDuration Duration
final
analysisLevel String
final
changedFiles List<String>
final
changedSymbols List<String>
final
fallbackExplanation String?
final
fallbackReason String?
final
hashCode int
The hash code for this object.
no setterinherited
impactPaths List<SymbolImpactPath>
final
isFallback bool
final
mode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
totalTests int
final
unaffectedCount int
no setter
unaffectedTests List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited