SourceFile class

Constructors

SourceFile({required String path, required String contentHash, required List<String> imports, List<String> exports = const [], bool isTest = false, bool isGenerated = false})
SourceFile.fromJson(Map<String, dynamic> json)
factory

Properties

contentHash String
final
exports List<String>
final
hashCode int
The hash code for this object.
no setterinherited
imports List<String>
final
isGenerated bool
final
isTest bool
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited