TestRunner class

Constructors

TestRunner({required String projectRoot, required bool isFlutterProject})

Properties

hashCode int
The hash code for this object.
no setterinherited
isFlutterProject bool
final
projectRoot String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runTests(List<String> testFiles) Future<TestRunnerResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited