AnalysisCache class
Constructors
- AnalysisCache({required String projectRoot})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
String relativePath, String currentContent) → SourceFile? -
load(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
String relativePath, SourceFile sourceFile) → void -
save(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited