CliOutput class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
printAffected(
ImpactResult result, {String? warningMessage, bool explain = false}) → void -
printAnalysis(
{required int fileCount, required int testCount, required int dependencyCount, int? symbolCount}) → void -
printHeader(
) → void -
printJson(
ImpactResult result) → void