GitChangesResult class
Constructors
Properties
-
added
→ List<
String> -
final
-
changedFiles
→ List<
String> -
final
-
deleted
→ List<
String> -
final
- fallbackReason → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isGitRepository → bool
-
final
-
modified
→ List<
String> -
final
- requiresFallback → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warningMessage → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited