ImpactAnalyzer class
Constructors
-
ImpactAnalyzer({required ProjectGraph graph, required List<
SourceFile> discoveredTests})
Properties
-
discoveredTests
→ List<
SourceFile> -
final
- graph → ProjectGraph
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyzeImpact(
{required List< String> changedFiles, Duration analysisDuration = Duration.zero, bool isGitRepo = true, bool gitRequiresFallback = false, String? gitFallbackReason, bool isConservative = false, bool forceAll = false, bool hasAnalysisErrors = false, String? analysisErrorReason}) → ImpactResult -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited