ProjectGraph class
Constructors
- ProjectGraph()
-
ProjectGraph.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nodes
→ Set<
String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalEdges → int
-
no setter
- totalNodes → int
-
no setter
Methods
-
addDependency(
String fromPath, String toPath) → void -
addNode(
String path) → void -
getDirectDependents(
String path) → Set< String> -
getDirectImports(
String path) → Set< String> -
getTransitiveDependents(
String startPath) → Map< String, List< String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited