SymbolGraph class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalEdges → int
-
no setter
- totalNodes → int
-
no setter
Methods
-
addDependency(
String dependentId, String targetId) → void -
addInheritance(
String childId, String parentId) → void -
addSymbol(
SymbolNode node) → void -
getAllSymbols(
) → List< SymbolNode> -
getDirectDependencies(
String dependentId) → Set< String> -
getDirectDependents(
String targetId) → Set< String> -
getSymbol(
String id) → SymbolNode? -
getTransitiveDependents(
String targetId) → Map< String, List< String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited